@@ -762,7 +762,7 @@ class TaskStatusHandle:
 
     def __str__(self):
         if self.current_status:
-            return f"{self.current_status.task_name} "+tqdm.format_meter(self.current_status.progress_current or 0, self.current_status.progress_total or 0, elapsed=self.current_status.duration_sec or 0) + f" [{self.current_status.state}]" +(f" >> Current subtask: {self.current_status.current_subtask}" if self.current_status.current_subtask else "" )
+            return f"{self.current_status.task_name} "+tqdm.format_meter(self.current_status.progress_current or 0, self.current_status.progress_total or 0, elapsed=self.current_status.duration_sec or 0) + f" [{self.current_status.state}]" +(f" >> Current subtask: {self.current_status.current_subtask}" if self.current_status.current_subtask else "" + (f"task_id: {self.task_id}") )
         else:
             return f"TaskStatusHandle(task_id:{self.task_id}, current_status:None)"
 
@@ -773,13 +773,14 @@ class TaskStatusHandle:
         wait_itterator = self._get_wait_until_finished_polling_generator(polling_interval_sec,timeout_sec)
         last_print_len=0
         print_out=""
+        print("")
         for _it in wait_itterator:
             if print_progress:
                 print_out=str(self)
-                print(print_out, end= (" "*(last_print_len-len(print_out))) +'\r', flush=True)
+                print('\r'+print_out, end= (" "*(last_print_len-len(print_out))), flush=True)
                 last_print_len=len(print_out)
         if print_progress:
-            print(str(self), end=(" "*(last_print_len-len(print_out))), flush=True)
+            print('\r'+str(self), end=(" "*(last_print_len-len(print_out))), flush=True)
 
     def refresh_status(self):
         self.current_status = self.client.tasks.get_task_status(self.task_id)
