@@ -16,27 +16,27 @@ from dataclasses import dataclass, field
 @dataclass
 class TextDocument:
     id:str
-    key:str
+    key:Optional[str]
     text:str
-    topic_id:Union[str,None]=None
+    #topic_id:Union[str,None]=None
     #topic_propability:Union[float,None] = field(init=False)
     labels:Union[List[str],None] =None
     predicted_labels:Union[List[str],None] = None
     predicted_label_scores:Union[Dict[str, float],None]=None
     context_data:Union[Dict[str,str],None]=None
-    excluded:bool = False
+    #excluded:bool = False
     _i:Union[int,None] = None
 
     COL_ID="id"
     COL_KEY="key"
     COL_TEXT="text"
     COL_LABELS="labels"
-    COL_TOPIC_ID="topic_id"
-    COL_TOPIC_PROPABILITY="topic_propability"
+    #COL_TOPIC_ID="topic_id"
+    #COL_TOPIC_PROPABILITY="topic_propability"
     COL_PREDICTED_LABELS="predicted_labels"
     COL_PREDICTED_LABEL_SCORES="predicted_label_scores"
     COL_CONTEXT_DATA="context_data"
-    COL_EXCLUDED="excluded"
+    #COL_EXCLUDED="excluded"
     COL_IINDEX="_i"
     _COL_VECTOR="vector"
 
@@ -53,11 +53,11 @@ class TextDocument:
             TextDocument.COL_ID, 
             TextDocument.COL_KEY, 
             TextDocument.COL_LABELS, 
-            TextDocument.COL_TOPIC_ID, 
-            TextDocument.COL_TOPIC_PROPABILITY, 
+            #TextDocument.COL_TOPIC_ID, 
+            #TextDocument.COL_TOPIC_PROPABILITY, 
             TextDocument.COL_PREDICTED_LABELS, 
             TextDocument.COL_CONTEXT_DATA, 
-            TextDocument.COL_EXCLUDED,
+            #TextDocument.COL_EXCLUDED,
             TextDocument.COL_IINDEX
             ]
 
